==> ignorance-1.3.0.1.tar.bz2: ignorance-1.3.0.1/interface.c <==
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"
#include "ignorance.h"

//#define GLADE_HOOKUP_OBJECT(component,widget,name) g_object_set_data_full (G_OBJECT (component), name, gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)
//
//#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) g_object_set_data (G_OBJECT (component), name, widget)
  
  
  
  

GtkWidget*
create_uiinfo (GPtrArray *levels)
{
  vbox1 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox1);

  vbox2 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox2);
  gtk_box_pack_start (GTK_BOX (vbox1), vbox2, TRUE, TRUE, 0);

  scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow1);
  gtk_box_pack_start (GTK_BOX (vbox2), scrolledwindow1, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow1), GTK_SHADOW_IN);

  store=gtk_tree_store_new(NUM_COLUMNS,G_TYPE_STRING,G_TYPE_STRING);
  
  levelView=gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
  
  renderer = gtk_cell_renderer_text_new ();
	column = gtk_tree_view_column_new_with_attributes ("Levels",renderer,"text", LEVEL_COLUMN,NULL);
	gtk_tree_view_append_column (GTK_TREE_VIEW (levelView), column);
	column = gtk_tree_view_column_new_with_attributes ("Rules",renderer,"text", RULE_COLUMN,NULL);
	gtk_tree_view_append_column (GTK_TREE_VIEW (levelView), column);  
	
	load_form_with_levels(GTK_TREE_VIEW(levelView),levels);
	
	gtk_widget_show(levelView);
	gtk_container_add(GTK_CONTAINER(scrolledwindow1),levelView);
	
	sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (levelView));
	gtk_tree_selection_set_mode (sel, GTK_SELECTION_SINGLE);  

  hbox1 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox1);
  gtk_box_pack_start (GTK_BOX (vbox2), hbox1, FALSE, FALSE, 0);

  levelAdd = gtk_button_new_from_stock ("gtk-add");
  gtk_widget_show (levelAdd);
  gtk_box_pack_start (GTK_BOX (hbox1), levelAdd, TRUE, TRUE, 0);

  levelEdit = gtk_button_new ();
  gtk_widget_show (levelEdit);
  gtk_box_pack_start (GTK_BOX (hbox1), levelEdit, TRUE, TRUE, 0);

  alignment1 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment1);
  gtk_container_add (GTK_CONTAINER (levelEdit), alignment1);

  hbox2 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox2);
  gtk_container_add (GTK_CONTAINER (alignment1), hbox2);

  image1 = gtk_image_new_from_stock ("gtk-yes", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image1);
  gtk_box_pack_start (GTK_BOX (hbox2), image1, FALSE, FALSE, 0);

  label1 = gtk_label_new_with_mnemonic (_("Modify"));
  gtk_widget_show (label1);
  gtk_box_pack_start (GTK_BOX (hbox2), label1, FALSE, FALSE, 0);

  levelDel = gtk_button_new_from_stock ("gtk-remove");
  gtk_widget_show (levelDel);
  gtk_box_pack_start (GTK_BOX (hbox1), levelDel, TRUE, TRUE, 0);

  rulename = gtk_entry_new ();
  gtk_widget_show (rulename);
  gtk_box_pack_start (GTK_BOX (vbox2), rulename, FALSE, FALSE, 0);
  gtk_entry_set_text (GTK_ENTRY (rulename), _("Rule Name"));

  hbox3 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox3);
  gtk_box_pack_start (GTK_BOX (vbox1), hbox3, FALSE, FALSE, 0);

  rulescorel = gtk_label_new (_("Violation score: "));
  gtk_widget_show (rulescorel);
  gtk_box_pack_start (GTK_BOX (hbox3), rulescorel, FALSE, FALSE, 0);

  score = gtk_entry_new ();
  gtk_widget_show (score);
  gtk_box_pack_start (GTK_BOX (hbox3), score, TRUE, TRUE, 0);

  vbox6 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox6);
  gtk_box_pack_start (GTK_BOX (vbox1), vbox6, TRUE, TRUE, 0);

  hbox8 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox8);
  gtk_box_pack_start (GTK_BOX (vbox6), hbox8, FALSE, TRUE, 0);

  label8 = gtk_label_new (_("Filter: "));
  gtk_widget_show (label8);
  gtk_box_pack_start (GTK_BOX (hbox8), label8, FALSE, FALSE, 0);

  filtervalue = gtk_entry_new ();
  gtk_widget_show (filtervalue);
  gtk_box_pack_start (GTK_BOX (hbox8), filtervalue, TRUE, TRUE, 0);

  hbox9 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox9);
  gtk_box_pack_start (GTK_BOX (vbox6), hbox9, FALSE, FALSE, 0);
  
  enabled_cb=gtk_check_button_new_with_mnemonic(_("Enabled"));
  gtk_widget_show(enabled_cb);
  gtk_box_pack_start(GTK_BOX(hbox9),enabled_cb,FALSE,FALSE,0);
  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(enabled_cb),TRUE);


  regex_cb = gtk_check_button_new_with_mnemonic (_("Regular Expression"));
  gtk_widget_show (regex_cb);
  gtk_box_pack_start (GTK_BOX (hbox9), regex_cb, FALSE, FALSE, 0);


  case_sens_cb = gtk_check_button_new_with_mnemonic (_("Case Sensitive"));
  gtk_widget_set_sensitive(case_sens_cb,FALSE);
  gtk_widget_show (case_sens_cb);
  gtk_box_pack_start (GTK_BOX (hbox9), case_sens_cb, FALSE, FALSE, 0);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (case_sens_cb), FALSE);
  

  frame3 = gtk_frame_new (NULL);
  gtk_widget_show (frame3);
  gtk_box_pack_start (GTK_BOX (vbox6), frame3, FALSE, TRUE, 0);

  alignment5 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_show (alignment5);
  gtk_container_add (GTK_CONTAINER (frame3), alignment5);
  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment5), 0, 0, 12, 0);

  table3 = gtk_table_new (3, 2, FALSE);
  gtk_widget_show (table3);
  gtk_container_add (GTK_CONTAINER (alignment5), table3);

  im_type_cb = gtk_check_button_new_with_mnemonic (_("IM Text"));
  gtk_widget_show (im_type_cb);
  gtk_table_attach (GTK_TABLE (table3), im_type_cb, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  chat_type_cb = gtk_check_button_new_with_mnemonic (_("Chat Text"));
  gtk_widget_show (chat_type_cb);
  gtk_table_attach (GTK_TABLE (table3), chat_type_cb, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chat_type_cb), TRUE);

  username_type_cb = gtk_check_button_new_with_mnemonic (_("User names"));
  gtk_widget_show (username_type_cb);
  gtk_table_attach (GTK_TABLE (table3), username_type_cb, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  enterleave_type_cb = gtk_check_button_new_with_mnemonic (_("Enter/Leave"));
  gtk_widget_show (enterleave_type_cb);
  gtk_table_attach (GTK_TABLE (table3), enterleave_type_cb, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  invite_type_cb = gtk_check_button_new_with_mnemonic (_("Invitations"));
  gtk_widget_set_sensitive(invite_type_cb,FALSE);
  gtk_widget_show (invite_type_cb);
  gtk_table_attach (GTK_TABLE (table3), invite_type_cb, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label9 = gtk_label_new (_("Filter"));
  gtk_widget_show (label9);
  gtk_frame_set_label_widget (GTK_FRAME (frame3), label9);

//  g_signal_connect ((gpointer) levelView, "select_cursor_row",
 //                   G_CALLBACK (on_levelView_row_activated),
  //                  NULL);
  
  g_signal_connect(GTK_WIDGET(vbox1), "destroy", G_CALLBACK(save_conf),NULL);
					
	g_signal_connect ((gpointer)sel, "changed",
                  G_CALLBACK (on_levelView_row_activated),
                  NULL);
					
  g_signal_connect ((gpointer) levelAdd, "clicked",
                    G_CALLBACK (on_levelAdd_clicked),
                    NULL);
  g_signal_connect ((gpointer) levelEdit, "clicked",
                    G_CALLBACK (on_levelEdit_clicked),
                    NULL);
  g_signal_connect ((gpointer) levelDel, "clicked",
                    G_CALLBACK (on_levelDel_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  //GLADE_HOOKUP_OBJECT_NO_REF (window1, window1, "window1");
//  GLADE_HOOKUP_OBJECT_NO_REF (vbox1, vbox1, "vbox1");
//  GLADE_HOOKUP_OBJECT (vbox1, vbox2, "vbox2");
//  GLADE_HOOKUP_OBJECT (vbox1, scrolledwindow1, "scrolledwindow1");
//  GLADE_HOOKUP_OBJECT (vbox1, levelView, "levelView");
//  GLADE_HOOKUP_OBJECT (vbox1, hbox1, "hbox1");
//  GLADE_HOOKUP_OBJECT (vbox1, levelAdd, "levelAdd");
//  GLADE_HOOKUP_OBJECT (vbox1, levelEdit, "levelEdit");
//  GLADE_HOOKUP_OBJECT (vbox1, alignment1, "alignment1");
//  GLADE_HOOKUP_OBJECT (vbox1, hbox2, "hbox2");
//  GLADE_HOOKUP_OBJECT (vbox1, image1, "image1");
//  GLADE_HOOKUP_OBJECT (vbox1, label1, "label1");
//  GLADE_HOOKUP_OBJECT (vbox1, levelDel, "levelDel");
//  GLADE_HOOKUP_OBJECT (vbox1, rulename, "rulename");
//  GLADE_HOOKUP_OBJECT (vbox1, hbox3, "hbox3");
//  GLADE_HOOKUP_OBJECT (vbox1, rulescorel, "rulescorel");
//  GLADE_HOOKUP_OBJECT (vbox1, score, "score");
//  GLADE_HOOKUP_OBJECT (vbox1, vbox6, "vbox6");
//  GLADE_HOOKUP_OBJECT (vbox1, hbox8, "hbox8");
//  GLADE_HOOKUP_OBJECT (vbox1, label8, "label8");
//  GLADE_HOOKUP_OBJECT (vbox1, filtervalue, "filtervalue");
//  GLADE_HOOKUP_OBJECT (vbox1, hbox9, "hbox9");
//  GLADE_HOOKUP_OBJECT (vbox1, case_sens_cb, "case_sens_cb");
//  GLADE_HOOKUP_OBJECT (vbox1, regex_cb, "regex_cb");
//  GLADE_HOOKUP_OBJECT (vbox1, frame3, "frame3");
//  GLADE_HOOKUP_OBJECT (vbox1, alignment5, "alignment5");
//  GLADE_HOOKUP_OBJECT (vbox1, table3, "table3");
//  GLADE_HOOKUP_OBJECT (vbox1, im_type_cb, "im_type_cb");
//  GLADE_HOOKUP_OBJECT (vbox1, chat_type_cb, "chat_type_cb");
//  GLADE_HOOKUP_OBJECT (vbox1, username_type_cb, "username_type_cb");
//  GLADE_HOOKUP_OBJECT (vbox1, enterleave_type_cb, "enterleave_type_cb");
//  GLADE_HOOKUP_OBJECT (vbox1, invite_type_cb, "invite_type_cb");
//  GLADE_HOOKUP_OBJECT (vbox1, label9, "label9");

  return vbox1;
}

==> ignorance-1.3.1.2.tar.bz2: ignorance-1.3.1.2/interface.c <==
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"
#include "ignorance.h"

//#define GLADE_HOOKUP_OBJECT(component,widget,name) g_object_set_data_full (G_OBJECT (component), name, gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)
//
//#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) g_object_set_data (G_OBJECT (component), name, widget)
  
  
  
  

GtkWidget*
create_uiinfo (GPtrArray *levels)
{
  vbox1 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox1);

  vbox2 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox2);
  gtk_box_pack_start (GTK_BOX (vbox1), vbox2, TRUE, TRUE, 0);

  scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow1);
  gtk_box_pack_start (GTK_BOX (vbox2), scrolledwindow1, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow1), GTK_SHADOW_IN);

  store=gtk_tree_store_new(NUM_COLUMNS,G_TYPE_STRING,G_TYPE_STRING);
  
  levelView=gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
  
  renderer = gtk_cell_renderer_text_new ();
	column = gtk_tree_view_column_new_with_attributes ("Levels",renderer,"text", LEVEL_COLUMN,NULL);
	gtk_tree_view_append_column (GTK_TREE_VIEW (levelView), column);
	column = gtk_tree_view_column_new_with_attributes ("Rules",renderer,"text", RULE_COLUMN,NULL);
	gtk_tree_view_append_column (GTK_TREE_VIEW (levelView), column);  
	
	load_form_with_levels(GTK_TREE_VIEW(levelView),levels);
	
	gtk_widget_show(levelView);
	gtk_container_add(GTK_CONTAINER(scrolledwindow1),levelView);
	
	sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (levelView));
	gtk_tree_selection_set_mode (sel, GTK_SELECTION_SINGLE);  

  hbox1 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox1);
  gtk_box_pack_start (GTK_BOX (vbox2), hbox1, FALSE, FALSE, 0);

  levelAdd = gtk_button_new_from_stock ("gtk-add");
  gtk_widget_show (levelAdd);
  gtk_box_pack_start (GTK_BOX (hbox1), levelAdd, TRUE, TRUE, 0);

  levelEdit = gtk_button_new ();
  gtk_widget_show (levelEdit);
  gtk_box_pack_start (GTK_BOX (hbox1), levelEdit, TRUE, TRUE, 0);

  alignment1 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment1);
  gtk_container_add (GTK_CONTAINER (levelEdit), alignment1);

  hbox2 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox2);
  gtk_container_add (GTK_CONTAINER (alignment1), hbox2);

  image1 = gtk_image_new_from_stock ("gtk-yes", GTK_ICON_SIZE_BUTTON);
  gtk_widget_show (image1);
  gtk_box_pack_start (GTK_BOX (hbox2), image1, FALSE, FALSE, 0);

  label1 = gtk_label_new_with_mnemonic (_("Modify"));
  gtk_widget_show (label1);
  gtk_box_pack_start (GTK_BOX (hbox2), label1, FALSE, FALSE, 0);

  levelDel = gtk_button_new_from_stock ("gtk-remove");
  gtk_widget_show (levelDel);
  gtk_box_pack_start (GTK_BOX (hbox1), levelDel, TRUE, TRUE, 0);

  rulename = gtk_entry_new ();
  gtk_widget_show (rulename);
  gtk_box_pack_start (GTK_BOX (vbox2), rulename, FALSE, FALSE, 0);
  gtk_entry_set_text (GTK_ENTRY (rulename), _("Rule Name"));

  hbox3 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox3);
  gtk_box_pack_start (GTK_BOX (vbox1), hbox3, FALSE, FALSE, 0);

  rulescorel = gtk_label_new (_("Violation score: "));
  gtk_widget_show (rulescorel);
  gtk_box_pack_start (GTK_BOX (hbox3), rulescorel, FALSE, FALSE, 0);

  score = gtk_entry_new ();
  gtk_widget_show (score);
  gtk_box_pack_start (GTK_BOX (hbox3), score, TRUE, TRUE, 0);

  vbox6 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox6);
  gtk_box_pack_start (GTK_BOX (vbox1), vbox6, TRUE, TRUE, 0);

  hbox8 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox8);
  gtk_box_pack_start (GTK_BOX (vbox6), hbox8, FALSE, TRUE, 0);

  label8 = gtk_label_new (_("Filter: "));
  gtk_widget_show (label8);
  gtk_box_pack_start (GTK_BOX (hbox8), label8, FALSE, FALSE, 0);

  filtervalue = gtk_entry_new ();
  gtk_widget_show (filtervalue);
  gtk_box_pack_start (GTK_BOX (hbox8), filtervalue, TRUE, TRUE, 0);

  hbox9 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox9);
  gtk_box_pack_start (GTK_BOX (vbox6), hbox9, FALSE, FALSE, 0);
  
  enabled_cb=gtk_check_button_new_with_mnemonic(_("Enabled"));
  gtk_widget_show(enabled_cb);
  gtk_box_pack_start(GTK_BOX(hbox9),enabled_cb,FALSE,FALSE,0);
  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(enabled_cb),TRUE);


  regex_cb = gtk_check_button_new_with_mnemonic (_("Regular Expression"));
  gtk_widget_show (regex_cb);
  gtk_box_pack_start (GTK_BOX (hbox9), regex_cb, FALSE, FALSE, 0);


  case_sens_cb = gtk_check_button_new_with_mnemonic (_("Case Sensitive"));
  gtk_widget_set_sensitive(case_sens_cb,FALSE);
  gtk_widget_show (case_sens_cb);
  gtk_box_pack_start (GTK_BOX (hbox9), case_sens_cb, FALSE, FALSE, 0);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (case_sens_cb), FALSE);
  

  frame3 = gtk_frame_new (NULL);
  gtk_widget_show (frame3);
  gtk_box_pack_start (GTK_BOX (vbox6), frame3, FALSE, TRUE, 0);

  alignment5 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_show (alignment5);
  gtk_container_add (GTK_CONTAINER (frame3), alignment5);
  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment5), 0, 0, 12, 0);

  table3 = gtk_table_new (3, 2, FALSE);
  gtk_widget_show (table3);
  gtk_container_add (GTK_CONTAINER (alignment5), table3);

  im_type_cb = gtk_check_button_new_with_mnemonic (_("IM Text"));
  gtk_widget_show (im_type_cb);
  gtk_table_attach (GTK_TABLE (table3), im_type_cb, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  chat_type_cb = gtk_check_button_new_with_mnemonic (_("Chat Text"));
  gtk_widget_show (chat_type_cb);
  gtk_table_attach (GTK_TABLE (table3), chat_type_cb, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chat_type_cb), TRUE);

  username_type_cb = gtk_check_button_new_with_mnemonic (_("User names"));
  gtk_widget_show (username_type_cb);
  gtk_table_attach (GTK_TABLE (table3), username_type_cb, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  enterleave_type_cb = gtk_check_button_new_with_mnemonic (_("Enter/Leave"));
  gtk_widget_show (enterleave_type_cb);
  gtk_table_attach (GTK_TABLE (table3), enterleave_type_cb, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  invite_type_cb = gtk_check_button_new_with_mnemonic (_("Invitations"));
  //gtk_widget_set_sensitive(invite_type_cb,FALSE);
  gtk_widget_show (invite_type_cb);
  gtk_table_attach (GTK_TABLE (table3), invite_type_cb, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label9 = gtk_label_new (_("Filter"));
  gtk_widget_show (label9);
  gtk_frame_set_label_widget (GTK_FRAME (frame3), label9);

//  g_signal_connect ((gpointer) levelView, "select_cursor_row",
 //                   G_CALLBACK (on_levelView_row_activated),
  //                  NULL);
  
  g_signal_connect(GTK_WIDGET(vbox1), "destroy", G_CALLBACK(save_conf),NULL);
					
	g_signal_connect ((gpointer)sel, "changed",
                  G_CALLBACK (on_levelView_row_activated),
                  NULL);
					
  g_signal_connect ((gpointer) levelAdd, "clicked",
                    G_CALLBACK (on_levelAdd_clicked),
                    NULL);
  g_signal_connect ((gpointer) levelEdit, "clicked",
                    G_CALLBACK (on_levelEdit_clicked),
                    NULL);
  g_signal_connect ((gpointer) levelDel, "clicked",
                    G_CALLBACK (on_levelDel_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  //GLADE_HOOKUP_OBJECT_NO_REF (window1, window1, "window1");
//  GLADE_HOOKUP_OBJECT_NO_REF (vbox1, vbox1, "vbox1");
//  GLADE_HOOKUP_OBJECT (vbox1, vbox2, "vbox2");
//  GLADE_HOOKUP_OBJECT (vbox1, scrolledwindow1, "scrolledwindow1");
//  GLADE_HOOKUP_OBJECT (vbox1, levelView, "levelView");
//  GLADE_HOOKUP_OBJECT (vbox1, hbox1, "hbox1");
//  GLADE_HOOKUP_OBJECT (vbox1, levelAdd, "levelAdd");
//  GLADE_HOOKUP_OBJECT (vbox1, levelEdit, "levelEdit");
//  GLADE_HOOKUP_OBJECT (vbox1, alignment1, "alignment1");
//  GLADE_HOOKUP_OBJECT (vbox1, hbox2, "hbox2");
//  GLADE_HOOKUP_OBJECT (vbox1, image1, "image1");
//  GLADE_HOOKUP_OBJECT (vbox1, label1, "label1");
//  GLADE_HOOKUP_OBJECT (vbox1, levelDel, "levelDel");
//  GLADE_HOOKUP_OBJECT (vbox1, rulename, "rulename");
//  GLADE_HOOKUP_OBJECT (vbox1, hbox3, "hbox3");
//  GLADE_HOOKUP_OBJECT (vbox1, rulescorel, "rulescorel");
//  GLADE_HOOKUP_OBJECT (vbox1, score, "score");
//  GLADE_HOOKUP_OBJECT (vbox1, vbox6, "vbox6");
//  GLADE_HOOKUP_OBJECT (vbox1, hbox8, "hbox8");
//  GLADE_HOOKUP_OBJECT (vbox1, label8, "label8");
//  GLADE_HOOKUP_OBJECT (vbox1, filtervalue, "filtervalue");
//  GLADE_HOOKUP_OBJECT (vbox1, hbox9, "hbox9");
//  GLADE_HOOKUP_OBJECT (vbox1, case_sens_cb, "case_sens_cb");
//  GLADE_HOOKUP_OBJECT (vbox1, regex_cb, "regex_cb");
//  GLADE_HOOKUP_OBJECT (vbox1, frame3, "frame3");
//  GLADE_HOOKUP_OBJECT (vbox1, alignment5, "alignment5");
//  GLADE_HOOKUP_OBJECT (vbox1, table3, "table3");
//  GLADE_HOOKUP_OBJECT (vbox1, im_type_cb, "im_type_cb");
//  GLADE_HOOKUP_OBJECT (vbox1, chat_type_cb, "chat_type_cb");
//  GLADE_HOOKUP_OBJECT (vbox1, username_type_cb, "username_type_cb");
//  GLADE_HOOKUP_OBJECT (vbox1, enterleave_type_cb, "enterleave_type_cb");
//  GLADE_HOOKUP_OBJECT (vbox1, invite_type_cb, "invite_type_cb");
//  GLADE_HOOKUP_OBJECT (vbox1, label9, "label9");

  return vbox1;
}
